"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.payout_details_dto import PayoutDetailsDto
from eis.claim.model.regress_details_dto import RegressDetailsDto
from eis.claim.model.reserve_details_dto import ReserveDetailsDto
globals()['PayoutDetailsDto'] = PayoutDetailsDto
globals()['RegressDetailsDto'] = RegressDetailsDto
globals()['ReserveDetailsDto'] = ReserveDetailsDto
from eis.claim.model.create_regulation_item_request_dto import CreateRegulationItemRequestDto


class TestCreateRegulationItemRequestDto(unittest.TestCase):
    """CreateRegulationItemRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateRegulationItemRequestDto(self):
        """Test CreateRegulationItemRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateRegulationItemRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
