"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.update_payout_details_dto import UpdatePayoutDetailsDto
from eis.claim.model.update_reserve_details_dto import UpdateReserveDetailsDto
globals()['UpdatePayoutDetailsDto'] = UpdatePayoutDetailsDto
globals()['UpdateReserveDetailsDto'] = UpdateReserveDetailsDto
from eis.claim.model.update_regulation_item_request_dto_rest import UpdateRegulationItemRequestDtoRest


class TestUpdateRegulationItemRequestDtoRest(unittest.TestCase):
    """UpdateRegulationItemRequestDtoRest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateRegulationItemRequestDtoRest(self):
        """Test UpdateRegulationItemRequestDtoRest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateRegulationItemRequestDtoRest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
