"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.claim_partner_roles_api import ClaimPartnerRolesApi  # noqa: E501


class TestClaimPartnerRolesApi(unittest.TestCase):
    """ClaimPartnerRolesApi unit test stubs"""

    def setUp(self):
        self.api = ClaimPartnerRolesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_claim_partner_role(self):
        """Test case for create_claim_partner_role

        Create the claim partner role  # noqa: E501
        """
        pass

    def test_delete_claim_partner_role(self):
        """Test case for delete_claim_partner_role

        Delete the claim partner role  # noqa: E501
        """
        pass

    def test_get_claim_partner_role(self):
        """Test case for get_claim_partner_role

        Retrieve the claim partner role  # noqa: E501
        """
        pass

    def test_list_claim_partner_role(self):
        """Test case for list_claim_partner_role

        List claim partner roles  # noqa: E501
        """
        pass

    def test_update_claim_partner_role(self):
        """Test case for update_claim_partner_role

        Update the claim partner role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
