"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.settlement_class import SettlementClass
globals()['SettlementClass'] = SettlementClass
from eis.claim.model.list_settlements_response_class import ListSettlementsResponseClass


class TestListSettlementsResponseClass(unittest.TestCase):
    """ListSettlementsResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListSettlementsResponseClass(self):
        """Test ListSettlementsResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListSettlementsResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
