"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.claim_status_class import ClaimStatusClass


class TestClaimStatusClass(unittest.TestCase):
    """ClaimStatusClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClaimStatusClass(self):
        """Test ClaimStatusClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClaimStatusClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
