"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.settlements_api import SettlementsApi  # noqa: E501


class TestSettlementsApi(unittest.TestCase):
    """SettlementsApi unit test stubs"""

    def setUp(self):
        self.api = SettlementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_settlement(self):
        """Test case for create_settlement

        Create the settlement  # noqa: E501
        """
        pass

    def test_delete_settlement(self):
        """Test case for delete_settlement

        Delete the settlement  # noqa: E501
        """
        pass

    def test_get_settlement(self):
        """Test case for get_settlement

        Retrieve the settlement  # noqa: E501
        """
        pass

    def test_list_settlements(self):
        """Test case for list_settlements

        List settlements  # noqa: E501
        """
        pass

    def test_update_settlement(self):
        """Test case for update_settlement

        Update the settlement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
